[git] GpgOL - branch, master, updated. gpgol-1.2.0-103-ge1070f0

by Andre Heinecke cvs at cvs.gnupg.org
Fri Nov 13 10:41:26 CET 2015


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "GnuPG extension for MS Outlook".

The branch, master has been updated
       via  e1070f0012acbb57b04d0babda3d76d9266a91ff (commit)
       via  40a79500f09ebf6dac1c4be9155a0aa50d2176b8 (commit)
      from  4df4e26146ec45ea31c457f8ae124e11a0b42088 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit e1070f0012acbb57b04d0babda3d76d9266a91ff
Author: Andre Heinecke <aheinecke at intevation.de>
Date:   Fri Nov 13 10:40:17 2015 +0100

    Disable msgclass changing code for in Body Crypto
    
    * src/mapihelp.cpp (get_msgcls_from_pgp_lines): Disable for
      Outlook >= 2010.
    
    --
    For now we want to ignore clearsigned and PGP/Inline
    signed code as we still have the old body based interface
    for those. And before we handle them we should tackle
    some interoperability issues arising from our current
    handling (e.g. fix the wipe to restore the PGP body)

diff --git a/src/mapihelp.cpp b/src/mapihelp.cpp
index f6b0a9b..17032e0 100644
--- a/src/mapihelp.cpp
+++ b/src/mapihelp.cpp
@@ -543,7 +543,17 @@ get_msgcls_from_pgp_lines (LPMESSAGE message)
   char *msgcls = NULL;
   ULONG tag;
   int   is_binary = 0;
-  
+
+  if (g_ol_version_major >= 14)
+    {
+      /* XXX For now we want to ignore clearsigned and PGP/Inline
+         signed code as we still have the old body based interface
+         for those. And before we handle them we should tackle
+         some interoperability issues arising from our current
+         handling (e.g. fix the wipe to restore the PGP body) */
+      return NULL;
+    }
+
   hr = 0;
   if (!get_internetcharsetbody_tag (message, &tag) )
     {

commit 40a79500f09ebf6dac1c4be9155a0aa50d2176b8
Author: Andre Heinecke <aheinecke at intevation.de>
Date:   Fri Nov 13 10:34:11 2015 +0100

    Check PGP Body tags for additional msgtypes
    
    * src/mapihelp.cpp (change_message_class_ipm_note),
      (change_message_class_ipm_note_secure_cex): Also check
      multipart/alternative and multipart/mixed.
    
    --
    Especially PGP/Inline mails sent by Outlook with the old code
    is often times multipart/alternative as Outlook sends this by
    default.

diff --git a/src/mapihelp.cpp b/src/mapihelp.cpp
index abd5d9b..f6b0a9b 100644
--- a/src/mapihelp.cpp
+++ b/src/mapihelp.cpp
@@ -904,18 +904,16 @@ change_message_class_ipm_note (LPMESSAGE message)
             }
           xfree (proto);
         }
-      else if (!strcmp (ct, "text/plain"))
+      else if (!strcmp (ct, "text/plain") ||
+               !strcmp (ct, "multipart/mixed") ||
+               !strcmp (ct, "multipart/alternative"))
         {
-          newvalue = get_msgcls_from_pgp_lines (message);
-        }
-      else if (!strcmp (ct, "multipart/mixed"))
-        {
-          /* It is quite common to have a multipart/mixed mail with
-             separate encrypted PGP parts.  Look at the body to
+          /* It is quite common to have a multipart/mixed or alternative
+             mail with separate encrypted PGP parts.  Look at the body to
              decide.  */
           newvalue = get_msgcls_from_pgp_lines (message);
         }
-      
+
       xfree (ct);
     }
   else
@@ -1091,7 +1089,9 @@ change_message_class_ipm_note_secure_cex (LPMESSAGE message, int is_cexenc)
             }
         }
       
-      if (!newvalue && !strcmp (ct, "text/plain"))
+      if (!newvalue && (!strcmp (ct, "text/plain") ||
+                        !strcmp (ct, "multipart/alternative") ||
+                        !strcmp (ct, "multipart/mixed")))
         {
           newvalue = get_msgcls_from_pgp_lines (message);
         }

-----------------------------------------------------------------------

Summary of changes:
 src/mapihelp.cpp | 30 ++++++++++++++++++++----------
 1 file changed, 20 insertions(+), 10 deletions(-)


hooks/post-receive
-- 
GnuPG extension for MS Outlook
http://git.gnupg.org




More information about the Gnupg-commits mailing list